@@ -82,11 +82,14 @@ class Embeddings(BaseMatcher):
         self.top_n = top_n
         self.cosine_method = cosine_method
 
+        self.embeddings_to = None
+
     def match(self,
               from_list: List[str],
               to_list: List[str] = None,
               embeddings_from: np.ndarray = None,
-              embeddings_to: np.ndarray = None) -> pd.DataFrame:
+              embeddings_to: np.ndarray = None,
+              re_train: bool = True) -> pd.DataFrame:
         """ Matches the two lists of strings to each other and returns the best mapping
 
         Arguments:
@@ -94,6 +97,8 @@ class Embeddings(BaseMatcher):
             to_list: The list where you want to map to
             embeddings_from: Embeddings you created yourself from the `from_list`
             embeddings_to: Embeddings you created yourself from the `to_list`
+            re_train: Whether to re-train the model with new embeddings
+                      Set this to False if you want to use this model in production
 
         Returns:
             matches: The best matches between the lists of strings
@@ -106,10 +111,15 @@ class Embeddings(BaseMatcher):
                               ["string_three", "string_four"])
         ```
         """
+        # Extract embeddings from the `from_list`
         if not isinstance(embeddings_from, np.ndarray):
             embeddings_from = self._embed(from_list)
+
+        # Extract embeddings from the `to_list` if it exists
         if not isinstance(embeddings_to, np.ndarray):
-            if to_list is None:
+            if not re_train:
+                embeddings_to = self.embeddings_to
+            elif to_list is None:
                 embeddings_to = self._embed(from_list)
             else:
                 embeddings_to = self._embed(to_list)
@@ -120,6 +130,8 @@ class Embeddings(BaseMatcher):
                                     top_n=self.top_n,
                                     method=self.cosine_method)
 
+        self.embeddings_to = embeddings_to
+
         return matches
 
     def _embed(self, strings: List[str]) -> np.ndarray:
